summaryrefslogtreecommitdiffstats
path: root/lib/libalpm
diff options
context:
space:
mode:
authorAllan McRae <allan@archlinux.org>2011-06-28 06:35:17 +0200
committerAllan McRae <allan@archlinux.org>2011-06-28 15:28:23 +0200
commit37b6cceed41bc22d0d9fb1fe2f274067ddd2b2cc (patch)
tree0999ea05b87a25ddba8b4905cfeaa4bebd42533a /lib/libalpm
parent220842b37ba484a452f5e4d8071d91d3f2b6c2d4 (diff)
downloadpacman-37b6cceed41bc22d0d9fb1fe2f274067ddd2b2cc.tar.gz
pacman-37b6cceed41bc22d0d9fb1fe2f274067ddd2b2cc.tar.xz
Rename pmfileconflict_t to alpm_fileconflict_t
Signed-off-by: Allan McRae <allan@archlinux.org>
Diffstat (limited to 'lib/libalpm')
-rw-r--r--lib/libalpm/alpm.h4
-rw-r--r--lib/libalpm/conflict.c8
-rw-r--r--lib/libalpm/conflict.h2
3 files changed, 7 insertions, 7 deletions
diff --git a/lib/libalpm/alpm.h b/lib/libalpm/alpm.h
index ff966f18..90bb5405 100644
--- a/lib/libalpm/alpm.h
+++ b/lib/libalpm/alpm.h
@@ -129,12 +129,12 @@ typedef struct _alpm_conflict_t {
} alpm_conflict_t;
/** File conflict */
-typedef struct _pmfileconflict_t {
+typedef struct _alpm_fileconflict_t {
char *target;
alpm_fileconflicttype_t type;
char *file;
char *ctarget;
-} pmfileconflict_t;
+} alpm_fileconflict_t;
/** Package group */
typedef struct _pmgrp_t {
diff --git a/lib/libalpm/conflict.h b/lib/libalpm/conflict.h
index 4edbe620..6c13cb28 100644
--- a/lib/libalpm/conflict.h
+++ b/lib/libalpm/conflict.h
@@ -31,7 +31,7 @@ alpm_list_t *_alpm_outerconflicts(alpm_db_t *db, alpm_list_t *packages);
alpm_list_t *_alpm_db_find_fileconflicts(alpm_handle_t *handle,
alpm_list_t *upgrade, alpm_list_t *remove);
-void _alpm_fileconflict_free(pmfileconflict_t *conflict);
+void _alpm_fileconflict_free(alpm_fileconflict_t *conflict);
#endif /* _ALPM_CONFLICT_H */
diff --git a/lib/libalpm/conflict.c b/lib/libalpm/conflict.c
index 83a1fa5f..e54c7147 100644
--- a/lib/libalpm/conflict.c
+++ b/lib/libalpm/conflict.c
@@ -275,7 +275,7 @@ static alpm_list_t *filelist_operation(alpm_list_t *filesA, alpm_list_t *filesB,
return ret;
}
/* Adds pmfileconflict_t to a conflicts list. Pass the conflicts list, type
* (either PM_FILECONFLICT_TARGET or PM_FILECONFLICT_FILESYSTEM), a file
* string, and either two package names or one package name and NULL. This is
* a wrapper for former functionality that was done inline.
@@ -284,8 +284,8 @@ static alpm_list_t *add_fileconflict(alpm_handle_t *handle,
alpm_list_t *conflicts, alpm_fileconflicttype_t type, const char *filestr,
const char *name1, const char *name2)
{
- pmfileconflict_t *conflict;
- MALLOC(conflict, sizeof(pmfileconflict_t), goto error);
+ alpm_fileconflict_t *conflict;
+ MALLOC(conflict, sizeof(alpm_fileconflict_t), goto error);
conflict->type = type;
STRDUP(conflict->target, name1, goto error);
@@ -306,7 +306,7 @@ error:
RET_ERR(handle, PM_ERR_MEMORY, conflicts);
}
-void _alpm_fileconflict_free(pmfileconflict_t *conflict)
+void _alpm_fileconflict_free(alpm_fileconflict_t *conflict)
{
FREE(conflict->ctarget);
FREE(conflict->file);
@@ -275,7 +275,7 @@ static alpm_list_t *filelist_operation(alpm_list_t *filesA, alpm_list_t *filesB,
return ret;
}
-/* Adds pmfileconflict_t to a conflicts list. Pass the conflicts list, type
+/* Adds alpm_fileconflict_t to a conflicts list. Pass the conflicts list, type
* (either PM_FILECONFLICT_TARGET or PM_FILECONFLICT_FILESYSTEM), a file
* string, and either two package names or one package name and NULL. This is